@@ -5,15 +5,13 @@ from sql import Null
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 from trytond.model import fields
-from trytond import backend
 
 from .company import price_digits
 
 __all__ = ['TimesheetLine']
 
 
-class TimesheetLine:
-    __metaclass__ = PoolMeta
+class TimesheetLine(metaclass=PoolMeta):
     __name__ = 'timesheet.line'
 
     cost_price = fields.Numeric('Cost Price',
@@ -23,11 +21,10 @@ class TimesheetLine:
     def __register__(cls, module_name):
         pool = Pool()
         Employee = pool.get('company.employee')
-        TableHandler = backend.get('TableHandler')
 
         cursor = Transaction().connection.cursor()
         table = cls.__table__()
-        table_h = TableHandler(cls, module_name)
+        table_h = cls.__table_handler__(module_name)
 
         migrate_cost_price = not table_h.column_exist('cost_price')
 
